netapp_ontap.resources.anti_ransomware_volume_entropy_stats API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.anti_ransomware_volume_entropy_stats`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

This API returns the percentage of data classified as encrypted using an entropy algorithm, measured at various time intervals at the volume level. If no volume UUID is specified, entropy statistics of all the volumes will be returned. The entropy_stats_type parameter can be used to retrieve statistics with sub_hourly, hourly, or daily granularity. Additionally, it can be used to identify intervals that exhibited high (high_enc_pct) percentages of encrypted data. If no type is specified, all types of entropy statistics will be returned for the volumes.

## Examples

### Retrieving volume stats

In this example, the API returns the data-entropy statistics for the volumes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AntiRansomwareVolumeEntropyStats

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(AntiRansomwareVolumeEntropyStats.get_collection()))

Try it out

    [
        AntiRansomwareVolumeEntropyStats(
            {
                "_links": {
                    "self": {
                        "href": "/api/security/anti-ransomware/volume/entropy-stats/61edb8bb-b7d1-11ef-932d-005056bbaeff/sub_hourly/2024-12-13T03%3A36%3A24-05%3A00"
                    }
                },
                "entropy_stats_type": "sub_hourly",
                "data_written_in_bytes": 13249687,
                "volume": {"name": "v2", "uuid": "61edb8bb-b7d1-11ef-932d-005056bbaeff"},
                "encryption_percentage": 51,
                "timestamp": "2024-12-13T03:36:24-05:00",
                "duration": "PT10M21S",
            }
        ),
        AntiRansomwareVolumeEntropyStats(
            {
                "_links": {
                    "self": {
                        "href": "/api/security/anti-ransomware/volume/entropy-stats/61edb8bb-b7d1-11ef-932d-005056bbaeff/hourly/2024-12-13T04%3A16%3A06-05%3A00"
                    }
                },
                "entropy_stats_type": "hourly",
                "data_written_in_bytes": 13249687,
                "volume": {"name": "v2", "uuid": "61edb8bb-b7d1-11ef-932d-005056bbaeff"},
                "encryption_percentage": 51,
                "timestamp": "2024-12-13T04:16:06-05:00",
                "duration": "PT1H2M36S",
            }
        ),
    ]

## Classes

`class AntiRansomwareVolumeEntropyStats (*args, **kwargs)`

  Volume data-entropy statistics derived from block analysis.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all AntiRansomwareVolumeEntropyStats resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent AntiRansomwareVolumeEntropyStats resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the data-entropy statistics for the volumes.

    ### Learn more

    - `DOC /security/anti-ransomware/volume/entropy-stats`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves the data-entropy statistics for the volumes.

    ### Learn more

    - `DOC /security/anti-ransomware/volume/entropy-stats`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves a data-entropy statistic for the volumes.

    ### Learn more

    - `DOC /security/anti-ransomware/volume/entropy-stats`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class AntiRansomwareVolumeEntropyStatsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AntiRansomwareVolumeEntropyStats object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `data_written_in_bytes: Size GET`

    The amount of data written.

  `duration: str GET`

    The duration of the interval associated with this statistic. The duration is represented in ISO-8601 standard format.

    Example: PT15M

  `encryption_percentage: Size GET`

    The percentage of data that is encrypted.

  `entropy_stats_type: str GET`

    Volume metrics are retrieved based on this statistic type.

    Valid choices:

    - sub_hourly
    - hourly
    - daily
    - high_enc_pct
  `links: SelfLink GET`

    The links field of the anti_ransomware_volume_entropy_stats.

  `timestamp: ImpreciseDateTime GET`

    Start time in date-time format.

  `volume: Volume GET`

    The volume field of the anti_ransomware_volume_entropy_stats.